@@ -148,8 +148,7 @@ const asn1_static_node pkix_asn1_tab[] = {
   { "BasicConstraints", 1610612741, NULL },
   { "cA", 1610645508, NULL },
   { NULL, 131081, NULL },
-  { "pathLenConstraint", 537411587, NULL },
-  { "0", 10, "MAX"},
+  { "pathLenConstraint", 16387, NULL },
   { "id-ce-nameConstraints", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "30"},
@@ -168,8 +167,7 @@ const asn1_static_node pkix_asn1_tab[] = {
   { NULL, 4104, "0"},
   { "maximum", 536895490, "BaseDistance"},
   { NULL, 4104, "1"},
-  { "BaseDistance", 1611137027, NULL },
-  { "0", 10, "MAX"},
+  { "BaseDistance", 1073741827, NULL },
   { "id-ce-policyConstraints", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "36"},
@@ -178,8 +176,7 @@ const asn1_static_node pkix_asn1_tab[] = {
   { NULL, 4104, "0"},
   { "inhibitPolicyMapping", 536895490, "SkipCerts"},
   { NULL, 4104, "1"},
-  { "SkipCerts", 1611137027, NULL },
-  { "0", 10, "MAX"},
+  { "SkipCerts", 1073741827, NULL },
   { "id-ce-cRLDistributionPoints", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "31"},
@@ -249,8 +246,7 @@ const asn1_static_node pkix_asn1_tab[] = {
   { "id-ce-cRLNumber", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "20"},
-  { "CRLNumber", 1611137027, NULL },
-  { "0", 10, "MAX"},
+  { "CRLNumber", 1073741827, NULL },
   { "id-ce-issuingDistributionPoint", 1879048204, NULL },
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "28"},
@@ -311,22 +307,6 @@ const asn1_static_node pkix_asn1_tab[] = {
   { NULL, 1073741825, "id-ce"},
   { NULL, 1, "24"},
   { "InvalidityDate", 1073741861, NULL },
-  { "VisibleString", 1610620935, NULL },
-  { NULL, 4360, "26"},
-  { "NumericString", 1610620935, NULL },
-  { NULL, 4360, "18"},
-  { "IA5String", 1610620935, NULL },
-  { NULL, 4360, "22"},
-  { "TeletexString", 1610620935, NULL },
-  { NULL, 4360, "20"},
-  { "PrintableString", 1610620935, NULL },
-  { NULL, 4360, "19"},
-  { "UniversalString", 1610620935, NULL },
-  { NULL, 4360, "28"},
-  { "BMPString", 1610620935, NULL },
-  { NULL, 4360, "30"},
-  { "UTF8String", 1610620935, NULL },
-  { NULL, 4360, "12"},
   { "id-pkix", 1879048204, NULL },
   { "iso", 1073741825, "1"},
   { "identified-organization", 1073741825, "3"},
@@ -719,9 +699,8 @@ const asn1_static_node pkix_asn1_tab[] = {
   { "ub-extension-attributes", 1074266122, "1"},
   { NULL, 2, "ExtensionAttribute"},
   { "ExtensionAttribute", 1610612741, NULL },
-  { "extension-attribute-type", 1611145219, NULL },
-  { NULL, 1073743880, "0"},
-  { "0", 10, "ub-extension-attributes"},
+  { "extension-attribute-type", 1610620931, NULL },
+  { NULL, 2056, "0"},
   { "extension-attribute-value", 541073421, NULL },
   { NULL, 1073743880, "1"},
   { "extension-attribute-type", 1, NULL },
@@ -827,8 +806,13 @@ const asn1_static_node pkix_asn1_tab[] = {
   { "MAX", 1074266122, "1"},
   { NULL, 7, NULL },
   { "terminal-type", 1342177283, "23"},
-  { "TerminalType", 1611137027, NULL },
-  { "0", 10, "ub-integer-options"},
+  { "TerminalType", 1610874883, NULL },
+  { "telex", 1073741825, "3"},
+  { "teletex", 1073741825, "4"},
+  { "g3-facsimile", 1073741825, "5"},
+  { "g4-facsimile", 1073741825, "6"},
+  { "ia5-terminal", 1073741825, "7"},
+  { "videotex", 1, "8"},
   { "teletex-domain-defined-attributes", 1342177283, "6"},
   { "TeletexDomainDefinedAttributes", 1612709899, NULL },
   { "ub-domain-defined-attributes", 1074266122, "1"},
