@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2026 Free Software Foundation, Inc.
+ * Copyright (C) 2019-2022 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -14,8 +14,9 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, see
- * <https://www.gnu.org/licenses/>.
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  */
 
 /*
@@ -29,7 +30,6 @@
    };   cat leak-d69d42ff01f6c3acca35dee27538a99e6821fced | ./corpus2array
  */
 
-#include <config.h>
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
